@@ -23,8 +23,12 @@ from sqlalchemy import types
 from sqlalchemy.orm import object_session
 from sqlalchemy.orm.util import has_identity
 from sqlalchemy.orm.properties import ColumnProperty
-from .fields import SelectField, SelectMultipleField
-from .validators import DateRange, Unique, If, Chain
+from wtforms_components import (
+    SelectField,
+    SelectMultipleField,
+    DateRange,
+    Unique,
+)
 from .utils import (
     is_date_column,
     is_integer_column,
@@ -35,9 +39,7 @@ from .utils import (
 
 
 __all__ = (
-    Chain,
     DateRange,
-    If,
     SelectMultipleField,
     Unique,
     is_date_column,
